@@ -138,7 +138,7 @@ fn version() -> String {
         .parse()
         .unwrap();
 
-    format!("{}.{}", major, minor)
+    format!("{major}.{minor}")
 }
 
 fn output() -> PathBuf {
@@ -163,6 +163,11 @@ fn fetch() -> io::Result<()> {
     let _ = std::fs::remove_dir_all(output_base_path.join(&clone_dest_dir));
     let status = Command::new("git")
         .current_dir(&output_base_path)
+        .args(if cfg!(target_os = "windows") {
+            vec!["-c", "core.autocrlf=false"]
+        } else {
+            vec![]
+        })
         .arg("clone")
         .arg("--depth=1")
         .arg("-b")
@@ -174,7 +179,7 @@ fn fetch() -> io::Result<()> {
     if status.success() {
         Ok(())
     } else {
-        Err(io::Error::new(io::ErrorKind::Other, "fetch failed"))
+        Err(io::Error::other("fetch failed"))
     }
 }
 
@@ -243,13 +248,48 @@ fn find_sysroot() -> Option<String> {
 
 fn build(sysroot: Option<&str>) -> io::Result<()> {
     let source_dir = source();
+    if cfg!(target_os = "windows") {
+        let path = env::var("PATH").unwrap_or_default();
+        let mut paths = env::split_paths(&path).collect::<Vec<_>>();
+        paths.push(source_dir.clone());
+        let new_path = env::join_paths(paths).unwrap();
+
+        let include = env::var("INCLUDE").unwrap_or_default();
+        let mut includes = env::split_paths(&include).collect::<Vec<_>>();
+        includes.push(source_dir.clone());
+        let new_include = env::join_paths(includes).unwrap();
+
+        env::set_var("PATH", &new_path);
+        env::set_var("INCLUDE", &new_include);
+    }
 
     // Command's path is not relative to command's current_dir
     let configure_path = source_dir.join("configure");
     assert!(configure_path.exists());
-    let mut configure = Command::new(&configure_path);
-    configure.current_dir(&source_dir);
+    let mut configure = if cfg!(target_os = "windows") {
+        if Command::new("sh")
+            .arg("-c")
+            .arg("echo ok")
+            .output()
+            .is_err()
+        {
+            return Err(io::Error::other(
+                "Failed to find 'sh.exe', which is required for building FFmpeg",
+            ));
+        }
 
+        let mut configure = Command::new("sh");
+        configure.arg(configure_path);
+        if cfg!(target_env = "msvc") {
+            configure.arg("--toolchain=msvc");
+        }
+
+        configure
+    } else {
+        Command::new(&configure_path)
+    };
+
+    configure.current_dir(&source_dir);
     configure.arg(format!("--prefix={}", search().to_string_lossy()));
 
     let target = env::var("TARGET").unwrap();
@@ -263,10 +303,10 @@ fn build(sysroot: Option<&str>) -> io::Result<()> {
         let cc = cc::Build::new();
 
         // Apple-clang needs this, -arch is not enough.
-        let target_flag = format!("--target={}", target);
+        let target_flag = format!("--target={target}");
         if cc.is_flag_supported(&target_flag).unwrap_or(false) {
-            configure.arg(format!("--extra-cflags={}", target_flag));
-            configure.arg(format!("--extra-ldflags={}", target_flag));
+            configure.arg(format!("--extra-cflags={target_flag}"));
+            configure.arg(format!("--extra-ldflags={target_flag}"));
         }
 
         configure.arg(format!(
@@ -284,7 +324,7 @@ fn build(sysroot: Option<&str>) -> io::Result<()> {
             if let Some(suffix_pos) = compiler.rfind('-') {
                 let prefix = compiler[0..suffix_pos].trim_end_matches("-wr"); // "wr-c++" compiler
 
-                configure.arg(format!("--cross-prefix={}-", prefix));
+                configure.arg(format!("--cross-prefix={prefix}-"));
             }
         }
     } else {
@@ -292,11 +332,24 @@ fn build(sysroot: Option<&str>) -> io::Result<()> {
         configure.arg("--extra-cflags=-march=native -mtune=native");
     }
 
+    if env::var("CARGO_CFG_TARGET_OS").as_deref() == Ok("windows") {
+        // essential librareis on windowsw
+        println!("cargo:rustc-link-lib=dylib=ole32");
+        println!("cargo:rustc-link-lib=dylib=oleaut32");
+        println!("cargo:rustc-link-lib=dylib=gdi32");
+        println!("cargo:rustc-link-lib=dylib=user32");
+        println!("cargo:rustc-link-lib=dylib=vfw32");
+        println!("cargo:rustc-link-lib=dylib=strmiids");
+        println!("cargo:rustc-link-lib=dylib=bcrypt");
+        println!("cargo:rustc-link-lib=dylib=shlwapi");
+        println!("cargo:rustc-link-lib=dylib=shell32");
+    }
+
     // for ios it is required to provide sysroot for both configure and bindgen
     // for macos the easiest way is to run xcrun, for other platform we support $SYSROOT var
     if env::var("CARGO_CFG_TARGET_OS").as_deref() == Ok("ios") {
         let sysroot = sysroot.expect("The sysroot is required for ios cross compilation, make sure to have available xcode or provide the $SYSROOT env var");
-        configure.arg(format!("--sysroot={}", sysroot));
+        configure.arg(format!("--sysroot={sysroot}"));
 
         let cc = Command::new("xcrun")
             .args(["--sdk", "iphoneos", "-f", "clang"])
@@ -315,7 +368,7 @@ fn build(sysroot: Option<&str>) -> io::Result<()> {
     if env::var("CARGO_CFG_TARGET_OS").as_deref() == Ok("android") {
         // cargo ndk auto populates rust env variables for android cross compilation
         // so we can just leverage the same compiler path and cflags for ffmpeg build
-        let android_cc_raw_path = env::var(format!("CC_{}", target)).expect("Missing CC path for android. Make sure to use cargo-ndk for adnrdoic cross compilation");
+        let android_cc_raw_path = env::var(format!("CC_{target}")).expect("Missing CC path for android. Make sure to use cargo-ndk for adnrdoic cross compilation");
         let android_cc_path = Path::new(&android_cc_raw_path);
         if !android_cc_path.exists() {
             panic!("Android CC path does not exists: {}", android_cc_raw_path);
@@ -334,7 +387,7 @@ fn build(sysroot: Option<&str>) -> io::Result<()> {
             ));
         }
 
-        if let Ok(android_target_flags) = env::var(format!("CFLAGS_{}", target)).as_deref() {
+        if let Ok(android_target_flags) = env::var(format!("CFLAGS_{target}")).as_deref() {
             configure.arg(format!("--extra-cflags={android_target_flags}"));
             configure.arg(format!("--extra-ldflags={android_target_flags}"));
         }
@@ -368,7 +421,11 @@ fn build(sysroot: Option<&str>) -> io::Result<()> {
     // make it static
     configure.arg("--enable-static");
     configure.arg("--disable-shared");
-    configure.arg("--enable-pthreads");
+    // windows includes threading in the standard library
+    #[cfg(not(target_env = "msvc"))]
+    {
+        configure.arg("--enable-pthreads");
+    }
 
     // position independent code
     configure.arg("--enable-pic");
@@ -414,6 +471,7 @@ fn build(sysroot: Option<&str>) -> io::Result<()> {
         .iter()
         .filter(|lib| lib.is_feature)
         .filter(|lib| !(lib.name == "avresample" && ffmpeg_major_version >= 5))
+        .filter(|lib| !(lib.name == "postproc" && ffmpeg_major_version >= 8))
     {
         switch(&mut configure, &lib.name.to_uppercase(), lib.name);
     }
@@ -538,7 +596,7 @@ fn build(sysroot: Option<&str>) -> io::Result<()> {
         // Additional configuration may be needed for CUDA toolkit path
         // This could be provided as an environment variable
         if let Ok(cuda_path) = env::var("CUDA_PATH") {
-            configure.arg(format!("--cuda-path={}", cuda_path));
+            configure.arg(format!("--cuda-path={cuda_path}"));
         }
     }
 
@@ -604,13 +662,10 @@ fn build(sysroot: Option<&str>) -> io::Result<()> {
             String::from_utf8_lossy(&output.stderr)
         );
 
-        return Err(io::Error::new(
-            io::ErrorKind::Other,
-            format!(
-                "configure failed {}",
-                String::from_utf8_lossy(&output.stderr)
-            ),
-        ));
+        return Err(io::Error::other(format!(
+            "configure failed {}",
+            String::from_utf8_lossy(&output.stderr)
+        )));
     }
 
     // run make
@@ -621,7 +676,7 @@ fn build(sysroot: Option<&str>) -> io::Result<()> {
         .status()?
         .success()
     {
-        return Err(io::Error::new(io::ErrorKind::Other, "make failed"));
+        return Err(io::Error::other("make failed"));
     }
 
     // run make install
@@ -631,7 +686,7 @@ fn build(sysroot: Option<&str>) -> io::Result<()> {
         .status()?
         .success()
     {
-        return Err(io::Error::new(io::ErrorKind::Other, "make install failed"));
+        return Err(io::Error::other("make install failed"));
     }
 
     Ok(())
@@ -670,7 +725,7 @@ fn check_features(
             }
         }
 
-        let include = format!("#include <{}>", header);
+        let include = format!("#include <{header}>");
         if !includes_code.contains(&include) {
             includes_code.push_str(&include);
             includes_code.push('\n');
@@ -686,19 +741,17 @@ fn check_features(
             #define {var}_is_defined 1
             #endif
             #endif
-        "#,
-            var = var
+        "#
         );
 
         let _ = write!(
             main_code,
             r#"printf("[{var}]%d%d\n", {var}, {var}_is_defined);
-            "#,
-            var = var
+            "#
         );
     }
 
-    let version_check_info = [("avcodec", 56, 62, 0, 108)];
+    let version_check_info = [("avcodec", 56, 63, 0, 108)];
     for &(lib, begin_version_major, end_version_major, begin_version_minor, end_version_minor) in
         version_check_info.iter()
     {
@@ -730,9 +783,7 @@ fn check_features(
                 {main_code}
                 return 0;
             }}
-           "#,
-        includes_code = includes_code,
-        main_code = main_code
+           "#
     )
     .expect("Write failed");
 
@@ -784,9 +835,9 @@ fn check_features(
         // Here so the features are listed for rust-ffmpeg at build time. Does
         // NOT represent activated features, just features that exist (hence the
         // lack of "=true" at the end)
-        println!(r#"cargo:{}="#, var);
+        println!(r#"cargo:{var}="#);
 
-        let var_str = format!("[{var}]", var = var);
+        let var_str = format!("[{var}]");
         let pos = var_str.len()
             + stdout
                 .find(&var_str)
@@ -812,12 +863,8 @@ fn check_features(
     {
         for version_major in begin_version_major..end_version_major {
             for version_minor in begin_version_minor..end_version_minor {
-                let search_str = format!(
-                    "[{lib}_version_greater_than_{version_major}_{version_minor}]",
-                    version_major = version_major,
-                    version_minor = version_minor,
-                    lib = lib
-                );
+                let search_str =
+                    format!("[{lib}_version_greater_than_{version_major}_{version_minor}]");
                 let pos = stdout
                     .find(&search_str)
                     .expect("Variable not found in output")
@@ -851,6 +898,7 @@ fn check_features(
         ("ffmpeg_6_1", 60, 31),
         ("ffmpeg_7_0", 61, 3),
         ("ffmpeg_7_1", 61, 19),
+        ("ffmpeg_8_0", 62, 8),
     ];
     for &(ffmpeg_version_flag, lavc_version_major, lavc_version_minor) in
         ffmpeg_lavc_versions.iter()
@@ -864,11 +912,15 @@ fn check_features(
             .find(&search_str)
             .expect("Variable not found in output")
             + search_str.len();
+        println!(
+            r#"cargo:rustc-check-cfg=cfg(feature, values("{}"))"#,
+            ffmpeg_version_flag
+        );
         if &stdout[pos..pos + 1] == "1" {
-            println!(r#"cargo:rustc-cfg=feature="{}""#, ffmpeg_version_flag);
-            println!(r#"cargo:{}=true"#, ffmpeg_version_flag);
+            println!(r#"cargo:rustc-cfg=feature="{ffmpeg_version_flag}""#);
+            println!(r#"cargo:{ffmpeg_version_flag}=true"#);
         } else {
-            println!(r#"cargo:{}="#, ffmpeg_version_flag);
+            println!(r#"cargo:{ffmpeg_version_flag}="#);
         }
     }
 }
@@ -880,7 +932,7 @@ fn search_include(include_paths: &[PathBuf], header: &str) -> String {
             return include.as_path().to_str().unwrap().to_string();
         }
     }
-    format!("/usr/include/{}", header)
+    format!("/usr/include/{header}")
 }
 
 fn maybe_search_include(include_paths: &[PathBuf], header: &str) -> Option<String> {
@@ -953,7 +1005,7 @@ fn main() {
                 .iter()
                 .filter(|flag| flag.starts_with("-l"))
                 .map(|lib| &lib[2..])
-                .for_each(|lib| println!("cargo:rustc-link-lib={}", lib));
+                .for_each(|lib| println!("cargo:rustc-link-lib={lib}"));
 
             extra_linker_args
                 .iter()
@@ -1046,7 +1098,7 @@ fn main() {
         }
 
         for (lib_name, env_variable_name) in libs.iter() {
-            if env::var(format!("CARGO_FEATURE_{}", env_variable_name)).is_ok() {
+            if env::var(format!("CARGO_FEATURE_{env_variable_name}")).is_ok() {
                 pkg_config::Config::new()
                     .statik(statik)
                     .probe(lib_name)
@@ -1086,7 +1138,7 @@ fn main() {
             "VideoToolbox",
         ];
         for f in frameworks {
-            println!("cargo:rustc-link-lib=framework={}", f);
+            println!("cargo:rustc-link-lib=framework={f}");
         }
     }
 
@@ -1499,7 +1551,7 @@ fn main() {
         .parse_callbacks(Box::new(Callbacks));
 
     if let Some(sysroot) = sysroot.as_deref() {
-        builder = builder.clang_arg(format!("--sysroot={}", sysroot));
+        builder = builder.clang_arg(format!("--sysroot={sysroot}"));
     }
 
     // The input headers we would like to generate
@@ -1508,11 +1560,14 @@ fn main() {
         builder = builder
             .header(search_include(&include_paths, "libavcodec/avcodec.h"))
             .header(search_include(&include_paths, "libavcodec/dv_profile.h"))
-            .header(search_include(&include_paths, "libavcodec/avfft.h"))
             .header(search_include(&include_paths, "libavcodec/vorbis_parser.h"));
 
         if ffmpeg_major_version < 5 {
-            builder = builder.header(search_include(&include_paths, "libavcodec/vaapi.h"))
+            builder = builder.header(search_include(&include_paths, "libavcodec/vaapi.h"));
+        }
+        let avfft_path = search_include(&include_paths, "libavcodec/avfft.h");
+        if std::path::Path::new(&avfft_path).exists() {
+            builder = builder.header(avfft_path);
         }
     }
 
@@ -1595,7 +1650,10 @@ fn main() {
         .header(search_include(&include_paths, "libavutil/xtea.h"));
 
     if env::var("CARGO_FEATURE_POSTPROC").is_ok() {
-        builder = builder.header(search_include(&include_paths, "libpostproc/postprocess.h"));
+        let postproc_path = search_include(&include_paths, "libpostproc/postprocess.h");
+        if std::path::Path::new(&postproc_path).exists() {
+            builder = builder.header(postproc_path);
+        }
     }
 
     if env::var("CARGO_FEATURE_SWRESAMPLE").is_ok() {
