@@ -1,6 +1,7 @@
 use super::constants::{HEXAGONS, PENTAGONS};
-use criterion::{black_box, Bencher, BenchmarkId, Criterion};
+use criterion::{Bencher, BenchmarkId, Criterion};
 use h3o::CellIndex;
+use std::hint::black_box;
 
 pub fn bench(c: &mut Criterion) {
     let mut group = c.benchmark_group("isValidCell");
