@@ -1,13 +1,13 @@
 use std::convert::TryInto;
 use std::ffi::c_void;
 use std::marker::PhantomData;
-use std::ops::Deref;
+use std::ops::{Deref, DerefMut};
 use std::{fmt, mem, ptr, slice};
 
 pub use mat_::*;
 
 use crate::boxed_ref::{BoxedRef, BoxedRefMut};
-use crate::core::{MatConstIterator, MatExpr, MatSize, Point, Rect, Scalar, Size, UMat};
+use crate::core::{MatConstIterator, MatExpr, MatSize, MatStep, Point, Rect, Scalar, Size, UMat};
 use crate::manual::core::DataType;
 use crate::prelude::*;
 use crate::{core, input_output_array, input_output_array_vector, Error, Result};
@@ -122,21 +122,22 @@ fn match_length(sizes: &[i32], slice_len: usize, size_mul: usize) -> Result<()>
 	Ok(())
 }
 
+/// Port of the algo from `Mat::at(int i0)`, includes OpenCV 5 specifics
 #[inline(always)]
-fn idx_to_row_col(mat: &(impl MatTraitConst + ?Sized), i0: i32) -> Result<(i32, i32)> {
-	Ok(if mat.is_continuous() {
-		(0, i0)
+unsafe fn data_at_idx<T: DataType>(mat: &(impl MatTraitConst + ?Sized), i0: usize) -> *const T {
+	let size = mat.mat_size();
+	let size = &*size;
+	let data = mat.data();
+	if size.len() <= 1 || mat.is_continuous() || size[0] == 1 {
+		unsafe { data.cast::<T>().add(i0) }
+	} else if size[1] == 1 {
+		unsafe { data.add(mat.mat_step()[0] * i0) }.cast::<T>()
 	} else {
-		let mat_size = mat.size()?;
-		if mat_size.width == 1 {
-			(0, i0)
-		} else if mat_size.height == 1 {
-			(i0, 0)
-		} else {
-			let i = i0 / mat_size.height;
-			(i, i0 - i * mat_size.height)
-		}
-	})
+		let cols = usize::try_from(size[1]).unwrap_or(1);
+		let i = i0 / cols;
+		let j = i0 - i * cols;
+		unsafe { data.add(mat.mat_step()[0] * i).cast::<T>().add(j) }
+	}
 }
 
 #[inline]
@@ -479,16 +480,7 @@ pub trait MatTraitConstManual: MatTraitConst {
 	/// Caller must ensure that index is within Mat bounds
 	#[inline]
 	unsafe fn at_unchecked<T: DataType>(&self, i0: i32) -> Result<&T> {
-		let mat_size = self.size()?;
-		let (i, j) = if self.is_continuous() || mat_size.width == 1 {
-			(0, i0)
-		} else if mat_size.height == 1 {
-			(i0, 0)
-		} else {
-			let i = i0 / mat_size.height;
-			(i, i0 - i * mat_size.height)
-		};
-		self.ptr_2d(i, j).map(|ptr| unsafe { convert_ptr(ptr) })
+		Ok(unsafe { &*data_at_idx::<T>(self, i0 as usize) })
 	}
 
 	/// Like `Mat::at_2d()` but performs no bounds or type checks
@@ -656,8 +648,7 @@ pub trait MatTraitManual: MatTraitConstManual + MatTrait {
 	/// Caller must ensure that index is within Mat bounds
 	#[inline]
 	unsafe fn at_unchecked_mut<T: DataType>(&mut self, i0: i32) -> Result<&mut T> {
-		let (i, j) = idx_to_row_col(self, i0)?;
-		self.ptr_2d_mut(i, j).map(|ptr| unsafe { convert_ptr_mut(ptr) })
+		Ok(unsafe { &mut *data_at_idx::<T>(self, i0 as usize).cast_mut() })
 	}
 
 	/// Like `Mat::at_2d_mut()` but performs no bounds or type checks
@@ -829,7 +820,7 @@ impl fmt::Debug for MatDataDumper<'_> {
 input_output_array! { UMat, from_umat, from_umat_mut }
 input_output_array_vector! { UMat, from_umat_vec, from_umat_vec_mut }
 
-impl Deref for MatSize {
+impl Deref for MatSize<'_> {
 	type Target = [i32];
 
 	#[inline]
@@ -844,12 +835,29 @@ impl Deref for MatSize {
 	}
 }
 
-impl fmt::Debug for MatSize {
+impl fmt::Debug for MatSize<'_> {
 	fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
 		writeln!(f, "{:#?}", self.deref())
 	}
 }
 
+impl Deref for MatStep {
+	#[cfg(not(ocvrs_opencv_branch_5))]
+	type Target = [usize; 2];
+	#[cfg(ocvrs_opencv_branch_5)]
+	type Target = [usize; 3];
+
+	fn deref(&self) -> &Self::Target {
+		self.buf()
+	}
+}
+
+impl DerefMut for MatStep {
+	fn deref_mut(&mut self) -> &mut Self::Target {
+		self.buf_mut()
+	}
+}
+
 pub trait MatConstIteratorTraitManual: MatConstIteratorTrait {
 	#[inline]
 	fn has_elements(&self) -> bool {
