@@ -97,6 +97,9 @@ fn mat_for_rows_and_cols() -> Result<()> {
 	assert_eq!(mast_step_len, mat.mat_step().buf().len());
 	assert_eq!(7200, mat.mat_step().buf()[0]);
 	assert_eq!(24, mat.mat_step().buf()[1]);
+	assert_eq!(mast_step_len, mat.mat_step().len());
+	assert_eq!(7200, mat.mat_step()[0]);
+	assert_eq!(24, mat.mat_step()[1]);
 	assert_eq!(24, mat.elem_size()?);
 	assert_eq!(8, mat.elem_size1());
 	assert_eq!(900, mat.step1(0)?);
@@ -606,12 +609,7 @@ fn mat_from_data() -> Result<()> {
 
 	{
 		let src = unsafe { Mat::new_nd_with_data_unsafe_def(&[3, 5, 6], u8::opencv_type(), bytes.as_mut_ptr().cast::<c_void>())? };
-		let expected_size = if cfg!(ocvrs_opencv_branch_5) {
-			Size::new(0, 0)
-		} else {
-			Size::new(5, 3)
-		};
-		assert_eq!(expected_size, src.size()?);
+		assert_eq!(&[3, 5, 6], &*src.mat_size());
 		assert_eq!(3, src.dims());
 		assert_eq!(-1, src.rows());
 		assert_eq!(-1, src.cols());
@@ -1301,28 +1299,13 @@ fn mat_dims_size() -> Result<()> {
 	}
 
 	// 0D Mat (Scalar)
-	{
+	if cfg!(ocvrs_opencv_branch_5) {
 		let mat = Mat::new_nd_with_data(&[], &[100])?;
 		assert_eq!(0, mat.dims());
-		let expected_rows_cols = if cfg!(ocvrs_opencv_branch_5) {
-			1
-		} else {
-			0
-		};
-		assert_eq!(expected_rows_cols, mat.rows());
-		assert_eq!(expected_rows_cols, mat.cols());
-		let expected_total = if cfg!(ocvrs_opencv_branch_5) {
-			1
-		} else {
-			0
-		};
-		assert_eq!(expected_total, mat.total());
-		let expected_size = if cfg!(ocvrs_opencv_branch_5) {
-			Size::new(1, 1)
-		} else {
-			Size::new(0, 0)
-		};
-		assert_eq!(expected_size, mat.size()?);
+		assert_eq!(1, mat.rows());
+		assert_eq!(1, mat.cols());
+		assert_eq!(1, mat.total());
+		assert_eq!(Size::new(1, 1), mat.size()?);
 	}
 	Ok(())
 }
