@@ -1,14 +1,13 @@
 use gtk::prelude::*;
+use relm4::Worker;
 use relm4::factory::{FactoryVecDeque, FactoryView};
 use relm4::prelude::*;
-use relm4::Worker;
 use relm4_components::open_dialog::{
     OpenDialog, OpenDialogMsg, OpenDialogResponse, OpenDialogSettings,
 };
 use relm4_components::save_dialog::{
     SaveDialog, SaveDialogMsg, SaveDialogResponse, SaveDialogSettings,
 };
-use relm4_icons::icon_names;
 use serde::{Deserialize, Serialize};
 use std::path::PathBuf;
 
@@ -81,7 +80,7 @@ impl FactoryComponent for Task {
                 },
 
                 gtk::Button {
-                    set_icon_name: icon_names::DELETE_FILLED,
+                    set_icon_name: "edit-delete",
                     set_tooltip: "Delete Task",
 
                     connect_clicked[sender, index] => move |_| {
@@ -95,7 +94,7 @@ impl FactoryComponent for Task {
                 set_orientation: gtk::Orientation::Horizontal,
 
                 gtk::MenuButton {
-                    set_icon_name: icon_names::TAG_OUTLINE_ADD,
+                    set_icon_name: "plus",
                     set_tooltip: "Add Tag",
 
                     #[wrap(Some)]
@@ -290,7 +289,7 @@ impl Worker for Document {
     fn update(&mut self, input: DocumentInput, sender: ComponentSender<Self>) {
         match input {
             DocumentInput::Save(path) => {
-                println!("Save as JSON to {:?}", path);
+                println!("Save as JSON to {path:?}");
 
                 // TODO in a real app you would report any errors from saving the document
                 if let Ok(json) = serde_json::to_string(&self.model) {
@@ -298,7 +297,7 @@ impl Worker for Document {
                 }
             }
             DocumentInput::Open(path) => {
-                println!("Open tasks document at {:?}", path);
+                println!("Open tasks document at {path:?}");
 
                 if let Ok(json) = std::fs::read_to_string(path) {
                     if let Ok(new_model) = serde_json::from_str(&json) {
@@ -429,7 +428,7 @@ impl SimpleComponent for App {
                     },
 
                     pack_start = &gtk::Button {
-                        set_icon_name: icon_names::PLUS,
+                        set_icon_name: "plus",
                         set_tooltip: "Add Task",
 
                         connect_clicked[sender] => move |_| {
@@ -470,7 +469,7 @@ impl SimpleComponent for App {
                     },
 
                     gtk::Button {
-                        set_icon_name: icon_names::DELETE_FILLED,
+                        set_icon_name: "edit-delete",
                         set_tooltip: "Delete All Tasks",
                         add_css_class: CSS_CLASS_DESTRUCTIVE_ACTION,
 
@@ -649,7 +648,5 @@ fn tasks_filename_filters() -> Vec<gtk::FileFilter> {
 fn main() {
     let app = RelmApp::new("relm4.example.state_management");
 
-    relm4_icons::initialize_icons();
-
     app.run::<App>(());
 }
