@@ -7,8 +7,8 @@ use crate::factory::{DynamicIndex, FactoryComponent, FactoryView};
 
 use super::{ModelStateValue, RenderedState};
 
-use std::collections::hash_map::DefaultHasher;
 use std::collections::VecDeque;
+use std::collections::hash_map::DefaultHasher;
 use std::hash::Hash;
 use std::iter::FusedIterator;
 use std::marker::PhantomData;
@@ -16,6 +16,7 @@ use std::ops::{Deref, Index, IndexMut};
 
 #[cfg(feature = "libadwaita")]
 use gtk::prelude::Cast;
+use gtk::prelude::IsA;
 
 #[cfg(feature = "libadwaita")]
 use std::hash::Hasher;
@@ -32,7 +33,7 @@ where
     inner: &'a mut FactoryVecDeque<C>,
 }
 
-impl<'a, C> Drop for FactoryVecDequeGuard<'a, C>
+impl<C> Drop for FactoryVecDequeGuard<'_, C>
 where
     C: FactoryComponent<Index = DynamicIndex>,
 {
@@ -354,7 +355,7 @@ where
     }
 }
 
-impl<'a, C> Deref for FactoryVecDequeGuard<'a, C>
+impl<C> Deref for FactoryVecDequeGuard<'_, C>
 where
     C: FactoryComponent<Index = DynamicIndex>,
 {
@@ -365,7 +366,7 @@ where
     }
 }
 
-impl<'a, C> Index<usize> for FactoryVecDequeGuard<'a, C>
+impl<C> Index<usize> for FactoryVecDequeGuard<'_, C>
 where
     C: FactoryComponent<Index = DynamicIndex>,
 {
@@ -376,7 +377,7 @@ where
     }
 }
 
-impl<'a, C> IndexMut<usize> for FactoryVecDequeGuard<'a, C>
+impl<C> IndexMut<usize> for FactoryVecDequeGuard<'_, C>
 where
     C: FactoryComponent<Index = DynamicIndex>,
 {
@@ -730,6 +731,19 @@ where
         }
         output
     }
+    /// Adds multiple components to the back of the [`FactoryVecDeque`].
+    ///
+    /// This method takes an iterator over components and adds each one
+    /// to the deque, rendering them efficiently.
+    pub fn extend(&mut self, component_iter: impl IntoIterator<Item = C::Init>) {
+        // Acquire the guard to make changes
+        let mut edit = self.guard();
+
+        // Iterate over the incoming components and push each one
+        for component in component_iter {
+            edit.push_back(component);
+        }
+    }
 }
 
 ///Implements the Clone Trait for `FactoryVecDeque<C>` where C is Cloneable
@@ -752,3 +766,23 @@ where
         clone
     }
 }
+
+impl<C> FactoryVecDeque<C>
+where
+    C: FactoryComponent<Index = DynamicIndex>,
+    C::ParentWidget: IsA<gtk::Stack>,
+    C::Root: IsA<gtk::Widget>,
+{
+    /// Makes the element at a given index visible in a [`gtk::Stack`].
+    /// Returns [`true`] on success, otherwise [`false`].
+    pub fn set_visible(&self, index: usize) -> bool {
+        if let Some(handle) = self.components.get(index) {
+            self.widget
+                .as_ref()
+                .set_visible_child(handle.widget().as_ref());
+            true
+        } else {
+            false
+        }
+    }
+}
