@@ -20,35 +20,6 @@ use std::{
 };
 use wide::{CmpEq, CmpGe, CmpGt, CmpLe, CmpLt, CmpNe};
 
-#[cfg(feature = "rkyv")]
-macro_rules! impl_rkyv {
-    ($type:ty, $array:ty) => {
-        impl rkyv::Archive for $type {
-            type Archived = $array;
-            type Resolver = ();
-
-            #[inline]
-            unsafe fn resolve(&self, _: usize, _: Self::Resolver, out: *mut Self::Archived) {
-                out.write((*self).into_arr());
-            }
-        }
-
-        impl<S: rkyv::Fallible + ?Sized> rkyv::Serialize<S> for $type {
-            #[inline]
-            fn serialize(&self, _: &mut S) -> Result<Self::Resolver, S::Error> {
-                Ok(())
-            }
-        }
-
-        impl<D: rkyv::Fallible + ?Sized> rkyv::Deserialize<$type, D> for rkyv::Archived<$type> {
-            #[inline]
-            fn deserialize(&self, _: &mut D) -> Result<$type, D::Error> {
-                Ok(<$type>::from_arr(*self))
-            }
-        }
-    };
-}
-
 /// A wrapper type of `wide::f32x4` that implements all the relevant traits from `num` and `simba`.
 ///
 /// This is needed to overcome the orphan rules.
@@ -56,9 +27,6 @@ macro_rules! impl_rkyv {
 #[derive(Copy, Clone, Debug)]
 pub struct WideF32x4(pub wide::f32x4);
 
-#[cfg(feature = "rkyv")]
-impl_rkyv!(WideF32x4, [f32; 4]);
-
 /// An SIMD boolean structure associated to `wide::f32x4` that implements all the relevant traits from `simba`.
 ///
 /// This is needed to overcome the orphan rules.
@@ -66,9 +34,6 @@ impl_rkyv!(WideF32x4, [f32; 4]);
 #[derive(Copy, Clone, Debug)]
 pub struct WideBoolF32x4(pub wide::f32x4);
 
-#[cfg(feature = "rkyv")]
-impl_rkyv!(WideBoolF32x4, [f32; 4]);
-
 /// A wrapper type of `wide::f32x8` that implements all the relevant traits from `num` and `simba`.
 ///
 /// This is needed to overcome the orphan rules.
@@ -76,9 +41,6 @@ impl_rkyv!(WideBoolF32x4, [f32; 4]);
 #[derive(Copy, Clone, Debug)]
 pub struct WideF32x8(pub wide::f32x8);
 
-#[cfg(feature = "rkyv")]
-impl_rkyv!(WideF32x8, [f32; 8]);
-
 /// An SIMD boolean structure associated to `wide::f32x8` that implements all the relevant traits from `simba`.
 ///
 /// This is needed to overcome the orphan rules.
@@ -86,9 +48,6 @@ impl_rkyv!(WideF32x8, [f32; 8]);
 #[derive(Copy, Clone, Debug)]
 pub struct WideBoolF32x8(pub wide::f32x8);
 
-#[cfg(feature = "rkyv")]
-impl_rkyv!(WideBoolF32x8, [f32; 8]);
-
 /// A wrapper type of `wide::f64x4` that implements all the relevant traits from `num` and `simba`.
 ///
 /// This is needed to overcome the orphan rules.
@@ -96,9 +55,6 @@ impl_rkyv!(WideBoolF32x8, [f32; 8]);
 #[derive(Copy, Clone, Debug)]
 pub struct WideF64x4(pub wide::f64x4);
 
-#[cfg(feature = "rkyv")]
-impl_rkyv!(WideF64x4, [f64; 4]);
-
 /// An SIMD boolean structure associated to `wide::f64x4` that implements all the relevant traits from `simba`.
 ///
 /// This is needed to overcome the orphan rules.
@@ -106,9 +62,6 @@ impl_rkyv!(WideF64x4, [f64; 4]);
 #[derive(Copy, Clone, Debug)]
 pub struct WideBoolF64x4(pub wide::f64x4);
 
-#[cfg(feature = "rkyv")]
-impl_rkyv!(WideBoolF64x4, [f64; 4]);
-
 macro_rules! impl_wide_f32(
     ($f32: ident, $f32xX: ident, $WideF32xX: ident, $WideBoolF32xX: ident, $lanes: expr; $($ii: expr),+) => {
         impl PrimitiveSimdValue for $WideF32xX {}
@@ -120,11 +73,6 @@ macro_rules! impl_wide_f32(
                 self.0.into()
             }
 
-            #[inline(always)]
-            fn from_arr(arr: [$f32; $lanes]) -> Self {
-                Self(arr.into())
-            }
-
             #[inline(always)]
             fn map(self, f: impl Fn($f32) -> $f32) -> Self {
                 let arr = self.into_arr();
